import objectdraw.*;
import java.awt.*;
import java.util.Random;

/*
 * A fancier version of the laundry sorting simulation
 * that uses nicer laundry baskets and which can
 * use any laundry object which implements the 
 * Laundry interface.
 *
 * Jim Teresco, The College of Saint Rose, Fall 2013
 * Based on example from Williams College CSCI 134
 *
 * $Id: ShirtsAndPants.java 2218 2013-10-18 14:06:39Z terescoj $
 */

public class ShirtsAndPants extends WindowController {
    // Constants controlling basket locations
    private static final int BASKETTOPS = 120;    
    private static final int BASKETLEFT = 20;
    private static final int BASKETOFFSET = 100;

    // Constants controlling shirt's position and size
    private static final int ITEMLEFT = 115;			
    private static final int ITEMTOP = 10;

    // Location where score should be displayed
    private static final int SCORELINE = 200;		
    private static final int SCORELEFT = 40;

    //The piece of laundry to be sorted.
    private Laundry item;  

    // baskets for white, dark, and color washing machines.
    private LaundryBasket white;
    private LaundryBasket dark;
    private LaundryBasket colors;

    // The basket corresponding to shirt's color
    private LaundryBasket correct;

    // Determines if next laundry should be a tshirt or a pair of pants
    private Random laundryGenerator = new Random();

    // Previously noted position of mouse cursor
    private Location lastPoint;

    // counters to measure trainees accuracy
    private int numsorted, mistakes;

    // Display of current result
    private Text scoreDisplay;

    // Initializes the applet by constructing all the objects.
    public void begin(){

        white =new LaundryBasket(BASKETLEFT + 0*BASKETOFFSET, 
            BASKETTOPS,"whites",canvas);
        dark  =new LaundryBasket(BASKETLEFT + 1*BASKETOFFSET, 
            BASKETTOPS,"darks",canvas);
        colors=new LaundryBasket(BASKETLEFT + 2*BASKETOFFSET,
            BASKETTOPS,"colors",canvas);

        item= new TShirt(ITEMLEFT,ITEMTOP,canvas);

        numsorted = 0;
        mistakes = 0;

        scoreDisplay = new Text("Correct: " + numsorted + 
            "    Incorrect: " + mistakes,
            SCORELEFT,SCORELINE,canvas);
        scoreDisplay.setFontSize(13);
    }

    // Whenever mouse is depressed, note its location
    public void onMousePress(Location point) {
        
        lastPoint = point;
    }

    // If mouse is dragged from a position within the item,
    // move the item with it
    public void onMouseDrag(Location point) {
        
        if (item.contains(lastPoint)) {
            item.move( point.getX() - lastPoint.getX(),
                point.getY() - lastPoint.getY());
            lastPoint = point;		
        }
    }

    // Checks if the item has been place in the correct basket
    public void onMouseRelease(Location point){

        if (item.contains(lastPoint)) { 
            // Determine correct basket
            if ( item.colorValue() > 600 ) {
                correct=white;
            }
            else if ( item.colorValue() > 250 ) {
                correct=colors;
            }
            else {
                correct=dark;
            }
        } 

        // if the object was dragged to the correct basket
        if ( correct.contains(point)) {
            numsorted++;
            item.removeFromCanvas();

            // Make a new item
            if (laundryGenerator.nextInt(2) == 1) {
                item = new TShirt(ITEMLEFT,ITEMTOP,canvas);
            }
            else {
                item = new Pants(ITEMLEFT,ITEMTOP,canvas);
            }
        }
        else {
            mistakes++;
            item.moveTo(ITEMLEFT, ITEMTOP);
        }

        scoreDisplay.setText("Correct: " + numsorted +
            "    Incorrect: " + mistakes);
    }
}
